@@ -1,6 +1,4 @@
 /* ============================================================
- *
- * This file is part of the KDE project
  *
  * SPDX-FileCopyrightText: 2008-2011 Kare Sars <kare.sars@iki .fi>
  *
@@ -39,12 +37,14 @@ public:
      * \param text is the text describing the checkbox.
      */
     KSaneButton(QWidget *parent, const QString &text);
+    KSaneButton(QWidget *parent, KSaneOption *option);
     ~KSaneButton();
 
 Q_SIGNALS:
-    void clicked();
+    void clicked(const QVariant &value);
 
 private:
+    void initButton(const QString &text);
     QPushButton *m_button;
 };
 
