@@ -1,9 +1,4 @@
 /* ============================================================
- *
- * This file is part of the KDE project
- *
- * Date        : 2007-09-13
- * Description : Sane interface for KDE
  *
  * SPDX-FileCopyrightText: 2007-2011 Kare Sars <kare.sars@iki .fi>
  * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
@@ -43,6 +38,7 @@ public:
      * \param text is the text describing the entry.
      */
     LabeledEntry(QWidget *parent, const QString &text);
+    LabeledEntry(QWidget *parent, KSaneOption *option);
     ~LabeledEntry();
     void setText(const QString &text);
 
@@ -50,12 +46,14 @@ private Q_SLOTS:
 
     void setClicked();
     void resetClicked();
+    void setValue(const QVariant &value);
 
 Q_SIGNALS:
 
     void entryEdited(const QString &text);
 
 private:
+    void initEntry();
 
     QLineEdit *m_entry;
     QPushButton *m_set;
